@@ -12,7 +12,8 @@
 
 #include <QVariant>
 
-namespace Akregator {
+namespace Akregator
+{
 class SettingsAdvanced;
 }
 
