@@ -12,10 +12,12 @@
 #include "akregatorinterfaces_export.h"
 #include <QHash>
 class QString;
-class QStringList;
+#include <QStringList>
 
-namespace Akregator {
-namespace Backend {
+namespace Akregator
+{
+namespace Backend
+{
 class StorageFactory;
 
 class AKREGATORINTERFACES_EXPORT StorageFactoryRegistry
