@@ -13,11 +13,11 @@
 #include "akregator_debug.h"
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <QUrl>
 #include <QDialogButtonBox>
 #include <QPushButton>
-#include <QVBoxLayout>
 #include <QStyle>
+#include <QUrl>
+#include <QVBoxLayout>
 
 using namespace Akregator;
 AddFeedWidget::AddFeedWidget(QWidget *parent)
@@ -50,7 +50,7 @@ AddFeedDialog::AddFeedDialog(QWidget *parent, const QString &name)
 {
     setObjectName(name);
     setWindowTitle(i18nc("@title:window", "Add Feed"));
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
 
     widget = new AddFeedWidget(this);
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
