@@ -18,6 +18,7 @@
 #include "kernel.h"
 #include "subscriptionlistjobs.h"
 #include <KLocalizedString>
+#include <limits>
 #include <memory>
 
 #include <QElapsedTimer>
@@ -37,7 +38,7 @@ public:
     Akregator::Backend::Storage *storage;
     QList<TreeNode *> flatList;
     Folder *rootNode;
-    QHash<int, TreeNode *> idMap;
+    QHash<uint, TreeNode *> idMap;
     AddNodeVisitor *addNodeVisitor;
     RemoveNodeVisitor *removeNodeVisitor;
     QHash<QString, QList<Feed *>> urlMap;
@@ -163,9 +164,9 @@ FeedList::FeedList(Backend::Storage *storage)
     addNode(rootNode, true);
 }
 
-QVector<int> FeedList::feedIds() const
+QVector<uint> FeedList::feedIds() const
 {
-    QVector<int> ids;
+    QVector<uint> ids;
     const auto f = feeds();
     for (const Feed *const i : f) {
         ids += i->id();
@@ -368,12 +369,12 @@ QDomDocument FeedList::toOpml() const
     return doc;
 }
 
-const TreeNode *FeedList::findByID(int id) const
+const TreeNode *FeedList::findByID(uint id) const
 {
     return d->idMap[id];
 }
 
-TreeNode *FeedList::findByID(int id)
+TreeNode *FeedList::findByID(uint id)
 {
     return d->idMap[id];
 }
@@ -436,7 +437,8 @@ void FeedList::setRootNode(Folder *folder)
 
 uint FeedList::generateID() const
 {
-    return QRandomGenerator::global()->generate();
+    // The values 0 and 1 are reserved, see TreeNode::id()
+    return QRandomGenerator::global()->bounded(2u, std::numeric_limits<quint32>::max());
 }
 
 void FeedList::slotNodeAdded(TreeNode *node)
