@@ -1,23 +1,23 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "grantleeviewformatter.h"
-#include "articlegrantleeobject.h"
-#include "utils.h"
 #include "akregatorconfig.h"
+#include "articlegrantleeobject.h"
 #include "grantleeutil.h"
+#include "utils.h"
 #include <KLocalizedString>
 
 #include <grantlee/engine.h>
 
-#include <QVariantHash>
 #include <QApplication>
+#include <QVariantHash>
 #include <QVariantList>
-#include <folder.h>
 #include <feed.h>
+#include <folder.h>
 
 using namespace Akregator;
 
@@ -45,7 +45,7 @@ void GrantleeViewFormatter::addStandardObject(QVariantHash &grantleeObject)
     grantleeObject.insert(QStringLiteral("absoluteThemePath"), mGrantleeThemePath);
     grantleeObject.insert(QStringLiteral("applicationDir"), mDirectionString);
     grantleeObject.insert(QStringLiteral("standardFamilyFont"), Settings::standardFont());
-    grantleeObject.insert(QStringLiteral("mediumFontSize"), pointsToPixel(Settings::mediumFontSize()));
+    grantleeObject.insert(QStringLiteral("mediumFontSize"), Settings::mediumFontSize());
 }
 
 QString GrantleeViewFormatter::formatFeed(Akregator::Feed *feed)
@@ -134,7 +134,7 @@ QString GrantleeViewFormatter::formatArticles(const QVector<Article> &article, A
     QList<ArticleGrantleeObject *> lstObj;
     lstObj.reserve(nbArticles);
     for (int i = 0; i < nbArticles; ++i) {
-        auto *articleObj = new ArticleGrantleeObject(article.at(i), icon);
+        auto articleObj = new ArticleGrantleeObject(article.at(i), icon);
         articlesList << QVariant::fromValue(static_cast<QObject *>(articleObj));
         lstObj.append(articleObj);
     }
